from tkdev_edit import Editor


if __name__ == '__main__':
    Root = Editor()
    Root.mainloop()